@@ -10,13 +10,10 @@ from signal import SIGINT, signal
 import kubernetes
 import yaml
 from benedict import benedict
-from kubernetes.dynamic import DynamicClient
-from kubernetes.dynamic.exceptions import (
-    ConflictError,
-    MethodNotAllowedError,
-    NotFoundError,
-)
-from kubernetes.dynamic.resource import ResourceField
+from kubernetes.dynamic.exceptions import ForbiddenError, MethodNotAllowedError
+from openshift.dynamic import DynamicClient
+from openshift.dynamic.exceptions import ConflictError, NotFoundError
+from openshift.dynamic.resource import ResourceField
 from packaging.version import Version
 from simple_logger.logger import get_logger
 
@@ -31,7 +28,6 @@ from ocp_resources.event import Event
 from ocp_resources.utils import (
     TimeoutExpiredError,
     TimeoutSampler,
-    TimeoutWatch,
     skip_existing_resource_creation_teardown,
 )
 
@@ -281,6 +277,7 @@ class Resource:
         NODE_LABELLER_KUBEVIRT_IO = "node-labeller.kubevirt.io"
         NMSTATE_IO = "nmstate.io"
         NODEMAINTENANCE_KUBEVIRT_IO = "nodemaintenance.kubevirt.io"
+        OCS_OPENSHIFT_IO = "ocs.openshift.io"
         OPERATOR_OPENSHIFT_IO = "operator.openshift.io"
         OPERATORS_COREOS_COM = "operators.coreos.com"
         OPERATORS_OPENSHIFT_IO = "operators.openshift.io"
@@ -633,7 +630,7 @@ class Resource:
         """
         try:
             return self.instance
-        except TimeoutExpiredError:
+        except NotFoundError:
             return None
 
     def client_wait_deleted(self, timeout):
@@ -681,19 +678,12 @@ class Resource:
             namespace=self.namespace,
         )
         current_status = None
-        last_logged_status = None
         try:
             for sample in samples:
                 if sample.items:
                     sample_status = sample.items[0].status
                     if sample_status:
                         current_status = sample_status.phase
-                        if current_status != last_logged_status:
-                            last_logged_status = current_status
-                            self.logger.info(
-                                f"Status of {self.kind} {self.name} is {current_status}"
-                            )
-
                         if current_status == status:
                             return
 
@@ -732,7 +722,7 @@ class Resource:
         resource_ = self.api.create(
             body=self.res, namespace=self.namespace, dry_run=self.dry_run
         )
-        with contextlib.suppress(TimeoutExpiredError, AttributeError):
+        with contextlib.suppress(NotFoundError, ForbiddenError):
             # some resources do not support get() (no instance) or the client do not have permissions
             self.initial_resource_version = self.instance.metadata.resourceVersion
 
@@ -800,19 +790,16 @@ class Resource:
     def retry_cluster_exceptions(
         func, exceptions_dict=DEFAULT_CLUSTER_RETRY_EXCEPTIONS, **kwargs
     ):
-        try:
-            sampler = TimeoutSampler(
-                wait_timeout=10,
-                sleep=1,
-                func=func,
-                print_log=False,
-                exceptions_dict=exceptions_dict,
-                **kwargs,
-            )
-            for sample in sampler:
-                return sample
-        except TimeoutExpiredError:
-            return None
+        sampler = TimeoutSampler(
+            wait_timeout=10,
+            sleep=1,
+            func=func,
+            print_log=False,
+            exceptions_dict=exceptions_dict,
+            **kwargs,
+        )
+        for sample in sampler:
+            return sample
 
     @classmethod
     def get(
@@ -918,18 +905,9 @@ class Resource:
             f" '{status}'"
         )
 
-        timeout_watcher = TimeoutWatch(timeout=timeout)
         for sample in TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            func=lambda: self.exists,
-        ):
-            if sample:
-                break
-
-        for sample in TimeoutSampler(
-            wait_timeout=timeout_watcher.remaining_time(),
-            sleep=1,
             func=lambda: self.instance,
         ):
             if sample:
@@ -964,19 +942,8 @@ class Resource:
             return response.data
 
     def wait_for_conditions(self):
-        timeout_watcher = TimeoutWatch(timeout=30)
-        for sample in TimeoutSampler(
-            wait_timeout=30,
-            sleep=1,
-            func=lambda: self.exists,
-        ):
-            if sample:
-                break
-
         samples = TimeoutSampler(
-            wait_timeout=timeout_watcher.remaining_time(),
-            sleep=1,
-            func=lambda: self.instance.status.conditions,
+            wait_timeout=30, sleep=1, func=lambda: self.instance.status.conditions
         )
         for sample in samples:
             if sample:
@@ -1149,8 +1116,8 @@ class NamespacedResource(Resource):
             dyn_client (DynamicClient): Open connection to remote cluster
             config_file (str): Path to config file for connecting to remote cluster.
             context (str): Context name for connecting to remote cluster.
-            singular_name (str): Resource kind (in lowercase), in use where we have multiple matches for resource.
-            raw (bool): If True return raw object.
+            singular_name (str): Resource kind (in lowercase), in use where we have multiple matches for resource
+            raw (bool): If True return raw object from openshift-restclient-python
 
 
         Returns:
@@ -1190,11 +1157,7 @@ class NamespacedResource(Resource):
         Returns:
             openshift.dynamic.client.ResourceInstance
         """
-
-        def _instance():
-            return self.api.get(name=self.name, namespace=self.namespace)
-
-        return self.retry_cluster_exceptions(func=_instance)
+        return self.api.get(name=self.name, namespace=self.namespace)
 
     def _base_body(self):
         if not self.res:
